

## for parsing GenePattern inputs
suppressMessages(suppressWarnings(library(getopt)))
suppressMessages(suppressWarnings(library(optparse)))

sessionInfo ()



timepoint.correlation <- function (data.file, output.file, timepoint.data.file='derisi-data.csv', method='pearson') {
  # calculate correlation of data with timepoint.data (usually derisi P. Falciparum 
  # life cycle time point data from DOI:10.1186/s13073-014-0110-6);
  # method can be "pearson", "kendall", "spearman";
  # both data sets should have the same ID schemes to identify genes, and 
  # the first column must be the ID column;
  # data sets must be in CSV format
  
  # read in data tables
  data <- read.csv (data.file)
  timepoint.data <- read.csv (timepoint.data.file)
  
  # assemble common data subset
  # if there are duplicate genes, pick the first occurance
  common.ids <- make.names (intersect (data[,1], timepoint.data[,1]))
  rownames (data) <- make.names (data[,1], unique=TRUE)
  rownames (timepoint.data) <- make.names (timepoint.data[,1], unique=TRUE)
  d.subset <- data [ common.ids, -1 ]
  tp.subset <- timepoint.data [ common.ids, -1 ]
  
  cor.table <- cor (tp.subset, d.subset, method=method)
  cor.table <- round (cor.table, digits=4)
  write.csv (cor.table, output.file)
}




# Get the command line arguments.  We'll process these with optparse.
# https://cran.r-project.org/web/packages/optparse/index.html
arguments <- commandArgs(trailingOnly=TRUE)

# Declare an option list for optparse to use in parsing the command line.
option_list <- list(
  # Note: it's not necessary for the names to match here, it's just a convention
  # to keep things consistent.
  make_option("--libdir", dest="libdir"),
  make_option("--input.file", dest="input.file"),
  make_option("--output.file", dest="output.file"),
  make_option("--correlation", dest="cor.type", default="pearson")
)

# Parse the command line arguments with the option list, printing the result
# to give a record as with sessionInfo.
opt <- parse_args (OptionParser (option_list=option_list), positional_arguments=TRUE, args=arguments)
print (opt)
opts <- opt$options


timepoint.correlation (opts$input.file, opts$output.file, 
                       timepoint.data.file=file.path (opts$libdir, 'derisi-data.csv'),
                       method=opts$cor.type)
